package com.example.what_the_fantasy.ui.screens

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.IconButton
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Brush
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.what_the_fantasy.R
import com.example.what_the_fantasy.ui.components.SpaceHeightComponent
import com.example.what_the_fantasy.ui.components.TitlePageComponent
import com.example.what_the_fantasy.ui.theme.What_The_FantasyTheme
import com.example.what_the_fantasy.ui.theme.colorBackground
import com.example.what_the_fantasy.ui.theme.gradienBox

@Composable
fun SignUpPage(navController: NavController) {


    Box(
        modifier = Modifier
            .fillMaxSize()
            .background(colorBackground),
        contentAlignment = Alignment.Center
    ){
        Column(
            modifier = Modifier
                .fillMaxWidth(0.9f)
                .padding(20.dp)
                .clip(RoundedCornerShape(16.dp))
                .background(gradienBox)
                .padding(20.dp),
            horizontalAlignment = Alignment.CenterHorizontally
        ) {

            TitlePageComponent(R.string.titleSignUp, 20,Color.White)
            IdentifiantTextFieldSign(R.string.IdentifiantLogin)
            EmailTextFieldSign("Email*")
            PassWdTextFieldSign(R.string.PasswdLogin)
            PassWdConfirmTextFieldSign(R.string.ConfirmPassWdSignUp)
            SpaceHeightComponent(16)
            ConnexionButtonSign(R.string.ButtonSignUp,18, Color.White, Color.Black)
            SpaceHeightComponent(16)
            CreateAccountButtonSign(R.string.ButtonLogin,12, Color.White, navController = navController)

        }
    }
}




@Composable
fun IdentifiantTextFieldSign(textIdentifiantResId : Int){
    val textIdentifiant = stringResource(id = textIdentifiantResId)
    var identifiant by remember { mutableStateOf("") } // Stocke la valeur du champ

    Column(modifier = Modifier.padding(top = 16.dp)) {
        OutlinedTextField(
            value = identifiant,
            onValueChange = { identifiant = it },
            label = { Text(textIdentifiant) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Text),
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}

@Composable
fun EmailTextFieldSign(textIdentifiant : String){
    var identifiant by remember { mutableStateOf("") } // Stocke la valeur du champ
    Column(modifier = Modifier.padding(top = 16.dp)) {
        OutlinedTextField(
            value = identifiant,
            onValueChange = { identifiant = it },
            label = { Text(textIdentifiant) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Email),
            shape = RoundedCornerShape(16.dp) // Bords arrondis
        )
    }
}

@Composable
fun PassWdTextFieldSign(textpasswdResId : Int){
    val textpasswd = stringResource(id = textpasswdResId)
    var passwd by remember { mutableStateOf("") } // Stocke la valeur du champ
    var passwordVisible by remember { mutableStateOf(false) } // État pour afficher/masquer
    Column(modifier = Modifier.padding(top = 10.dp)) {
        OutlinedTextField(
            value = passwd,
            onValueChange = { passwd = it },
            label = { Text(textpasswd) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            visualTransformation = if (passwordVisible) VisualTransformation.None else PasswordVisualTransformation(),
            trailingIcon = {
                IconButton(onClick = { passwordVisible = !passwordVisible }) {
                }
            },
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}

@Composable
fun PassWdConfirmTextFieldSign(textpasswdResId : Int){
    val textpasswd = stringResource(id = textpasswdResId)
    var passwd by remember { mutableStateOf("") } // Stocke la valeur du champ
    var passwordVisible by remember { mutableStateOf(false) } // État pour afficher/masquer
    Column(modifier = Modifier.padding(top = 10.dp)) {
        OutlinedTextField(
            value = passwd,
            onValueChange = { passwd = it },
            label = { Text(textpasswd) },
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 8.dp),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Password),
            visualTransformation = if (passwordVisible) VisualTransformation.None else PasswordVisualTransformation(),
            trailingIcon = {
                IconButton(onClick = { passwordVisible = !passwordVisible }) {
                }
            },
            shape = RoundedCornerShape(16.dp) // 🔹 Bords arrondis
        )
    }
}



@Composable
fun ConnexionButtonSign(titleResId : Int, size : Int, colorButton : Color, colorText : Color){
    val title = stringResource(id = titleResId)
    Button(
        onClick = { /* Action */ },
        colors = ButtonDefaults.buttonColors(containerColor = colorButton),
        modifier = Modifier
            .fillMaxWidth(),
    ) {
        Text(title, fontSize = size.sp, color = colorText)
    }
}

@Composable
fun CreateAccountButtonSign(titleResId: Int, size: Int, color: Color, navController: NavController) {
    val title = stringResource(id = titleResId)
    Text(
        text = title,
        fontSize = size.sp,
        color = color,
        modifier = Modifier.clickable {
            navController.popBackStack() //  Revenir à la page précédente
        }
    )
}
